@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client::Favorite;
 # ABSTRACT: A Favorite data object
-$MetaCPAN::Client::Favorite::VERSION = '2.004000';
+$MetaCPAN::Client::Favorite::VERSION = '2.005000';
 use Moo;
 
 with 'MetaCPAN::Client::Role::Entity';
@@ -43,13 +43,14 @@ MetaCPAN::Client::Favorite - A Favorite data object
 
 =head1 VERSION
 
-version 2.004000
+version 2.005000
 
 =head1 SYNOPSIS
 
-my $favorite = $mcpan->favorite( {
-    distribution => 'Moose'
-} );
+    my $favorites = $mcpan->favorite( {
+        distribution => 'Moose'
+    } );
+    while ( my $fav = $favorites->next ) { ... }
 
 =head1 DESCRIPTION
 
@@ -59,11 +60,13 @@ A MetaCPAN favorite entity object.
 
 =head2 date
 
-Date of the favorite.
+An ISO8601 datetime string like C<2016-11-19T12:41:46> indicating when the
+favorite was created.
 
 =head2 user
 
-The user ID (B<not> PAUSE ID) of who favorited.
+The user ID (B<not> PAUSE ID) of the person who favorited the thing in
+question.
 
 =head2 release
 
