@@ -2,10 +2,12 @@ use strict;
 use warnings;
 package MetaCPAN::Client::Pod;
 # ABSTRACT: A Pod object
-$MetaCPAN::Client::Pod::VERSION = '2.003000';
+$MetaCPAN::Client::Pod::VERSION = '2.005000';
 use Moo;
 use Carp;
 
+use MetaCPAN::Client::Types qw< Str >;
+
 has request => (
     is       => 'ro',
     handles  => [qw<ua fetch post ssearch>],
@@ -16,9 +18,7 @@ has name => ( is => 'ro', required => 1 );
 
 has url_prefix => (
     is  => 'ro',
-    isa => sub {
-        ref($_[0]) and croak "url_prefix must be a scalar";
-    }
+    isa => Str,
 );
 
 my @known_formats = qw<
@@ -62,7 +62,7 @@ MetaCPAN::Client::Pod - A Pod object
 
 =head1 VERSION
 
-version 2.003000
+version 2.005000
 
 =head1 SYNOPSIS
 
