@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client::Rating;
 # ABSTRACT: A Rating data object
-$MetaCPAN::Client::Rating::VERSION = '2.004000';
+$MetaCPAN::Client::Rating::VERSION = '2.005000';
 use Moo;
 
 with 'MetaCPAN::Client::Role::Entity';
@@ -52,11 +52,12 @@ MetaCPAN::Client::Rating - A Rating data object
 
 =head1 VERSION
 
-version 2.004000
+version 2.005000
 
 =head1 SYNOPSIS
 
-my $rating = $mcpan->rating({ distribution => "Moo" });
+    my $ratings = $mcpan->rating({ distribution => "Moo" });
+    while ( my $rat = $ratings->next ) { ... }
 
 =head1 DESCRIPTION
 
@@ -66,6 +67,9 @@ A MetaCPAN rating entity object.
 
 =head2 date
 
+An ISO8601 datetime string like C<2016-11-19T12:41:46> indicating when the
+rating was created.
+
 =head2 release
 
 =head2 author
